# Contacts & Acknowledgements

For any questions or further details about the project, please get in touch with any of the following contacts:

* **Jessica Lanini**, *jessica*[dot]*lanini*[at]*novartis*[dot]*com*
* **Minh Tam Davide Huynh**, *tamdavide*[dot]*huynh*[at]*gmail*[dot]*com*
* **Gaetano Scebba**, *gaetano*[dot]*scebba*[at]*novartis*[dot]*com*
* **Nadine Schneider**, *nadine-1*[dot]*schneider*[at]*novartis*[dot]*com*
* **Raquel Rodríguez-Pérez**, *raquel*[dot]*rodriguez_perez*[at]*novartis.com*

## Cite Us

If you find `UNIQUE` helpful for your work and/or research, please consider citing our work:

```bibtex
@misc{lanini2024unique,
  title={UNIQUE: A Framework for Uncertainty Quantification Benchmarking},
  author={Lanini, Jessica and Huynh, Minh Tam Davide and Scebba, Gaetano and Schneider, Nadine and Rodr{\'\i}guez-P{\'e}rez, Raquel},
  year={2024},
  doi={https://doi.org/10.26434/chemrxiv-2024-fmbgk},
}
```

:::{image} ../_static/novartis_logo.png
:alt: Novartis logo
:align: center
:class: dark-light
:::
